@@ -457,7 +457,7 @@ class Config:
         env_name = "_".join(filter(None, (self.__namespace, self.__attributes[name].env_name)))
         (k, v), = self.env.get_by_annotations(
             self,
-            key_to_name=lambda key: "_".join(filter(None, (self.__namespace, self.__info__[key].env_name))),
+            key_to_name=lambda key: env_name if key == name else "",
             name_is_setting=lambda name_: name_ == env_name,
         )
         assert name == k, (name, k, v)
